Rucio
======

Data Management for science in the Big Data era.

Rucio is a project that provides services and associated libraries for allowing scientific
collaborations to manage large volumes of data spread across facilities at
multiple institutions and organisations. Rucio has been developed by the
`ATLAS <https://atlas.cern/>`_. experiment. It offers advanced features, is
highly scalable and modular. Rucio is a data management
solution that could cover the needs of different communities in the scientific
domain (e.g., HEP, astronomy, biology).


Documentation
-------------

General information and latest documentation about Rucio can be found
at `readthedocs <http://rucio.readthedocs.io>`_.

Developers
----------

For information on how to contribute to Rucio, please refer and follow our
`CONTRIBUTING <CONTRIBUTING.rst>`_ guidelines.

Operators
----------

To learn how to deploy and configure Rucio, consult the `documentation <http://rucio.readthedocs.io/#operator-documentation>`_ available online.

Getting Support
----------------

If you are looking for support, please contact our mailing list rucio-users@googlegroups.com
or join us on our slack `support <https://rucio.slack.com/messages/#support>`_ channel.

